- :class:`cluster.MiniBatchKMeans` now correctly handles sample weights
  during fitting. When sample weights are not None, mini-batch
  indices are created by sub-sampling with replacement using the
  normalized sample weights as probabilities.
  By :user:`Shruti Nath <snath-xoc>`, :user:`Olivier Grisel <ogrisel>`,
  and :user:`Jeremie du Boisberranger <jeremiedbb>`.
